bayespy.inference.vmp.nodes.node.Moments.compute_dims_from_values
=================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.node

.. automethod:: Moments.compute_dims_from_values